Class: CircleSo::Resources::TaggedMembers

Inherits:
Base
  • Object
show all
Defined in:
lib/circle_so/resources/tagged_members.rb

Instance Method Summary collapse

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from CircleSo::Resources::Base

Instance Method Details

#add(**attrs) ⇒ Object



8
9
# File 'lib/circle_so/resources/tagged_members.rb', line 8

def add(**attrs) = client.post("/tagged_members", attrs)
# Removal identifies the record by query params, not the body.

#list(**params) ⇒ Object



6
# File 'lib/circle_so/resources/tagged_members.rb', line 6

def list(**params) = client.get("/tagged_members", params)

#remove(user_email:, member_tag_id:) ⇒ Object

Removal identifies the record by query params, not the body.



10
# File 'lib/circle_so/resources/tagged_members.rb', line 10

def remove(user_email:, member_tag_id:) = client.delete("/tagged_members", nil, {user_email: user_email, member_tag_id: member_tag_id})

#show(id) ⇒ Object



7
# File 'lib/circle_so/resources/tagged_members.rb', line 7

def show(id) = client.get("/tagged_members/#{id}")